<?php
/**
 * @file
 * accounting_modules.rules_defaults.inc
 */

/**
 * Implements hook_default_rules_configuration().
 */
function accounting_modules_default_rules_configuration() {
  $items = array();
  $items['rules_after_a_transaction_has_been_deleted'] = entity_import('rules_config', '{ "rules_after_a_transaction_has_been_deleted" : {
      "LABEL" : "After a transaction has been deleted",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_delete--transaction" : { "bundle" : "transaction" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ],
      "DO" : [
        { "entity_delete" : { "data" : [ "node:field-part-from" ] } },
        { "entity_delete" : { "data" : [ "node:field-part-to" ] } }
      ]
    }
  }');
  $items['rules_after_existing_transaction_has_been_updated'] = entity_import('rules_config', '{ "rules_after_existing_transaction_has_been_updated" : {
      "LABEL" : "After existing transaction has been updated",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_update--transaction" : { "bundle" : "transaction" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ],
      "DO" : [
        { "component_rules_update_transaction_parts" : { "transaction_node" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_after_saving_a_new_transaction'] = entity_import('rules_config', '{ "rules_after_saving_a_new_transaction" : {
      "LABEL" : "After saving a new transaction",
      "PLUGIN" : "reaction rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules" ],
      "ON" : { "node_insert--transaction" : { "bundle" : "transaction" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "part",
              "param_title" : "Part ID [node:nid]",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "created_part_from" : "Created Part from" } }
          }
        },
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "part",
              "param_title" : "Part ID [node:nid]",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "created_part_to" : "Created Part to" } }
          }
        },
        { "entity_save" : { "data" : [ "created-part-from" ], "immediate" : "1" } },
        { "entity_save" : { "data" : [ "created-part-to" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "created-part-from:field-transaction" ],
            "value" : [ "node" ]
          }
        },
        { "data_set" : { "data" : [ "created-part-to:field-transaction" ], "value" : [ "node" ] } },
        { "data_set" : {
            "data" : [ "created-part-from:field-part" ],
            "value" : [ "created-part-to" ]
          }
        },
        { "data_set" : {
            "data" : [ "created-part-to:field-part" ],
            "value" : [ "created-part-from" ]
          }
        },
        { "data_set" : { "data" : [ "node:field-part-from" ], "value" : [ "created-part-from" ] } },
        { "data_set" : { "data" : [ "node:field-part-to" ], "value" : [ "created-part-to" ] } },
        { "component_rules_update_transaction_parts" : { "transaction_node" : [ "node" ] } }
      ]
    }
  }');
  $items['rules_clone_account'] = entity_import('rules_config', '{ "rules_clone_account" : {
      "LABEL" : "Clone account",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Account" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : {
        "account_node" : { "label" : "Account node", "type" : "node" },
        "cloned_entity" : { "label" : "Cloned entity", "type" : "node", "parameter" : false }
      },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "account-node" ],
            "type" : "node",
            "bundle" : { "value" : { "account" : "account" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "account",
              "param_title" : "Temp account title",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:title" ],
            "value" : "[account-node:title] [CLONED]"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-reporting-group" ],
            "value" : [ "account-node:field-reporting-group" ]
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : { "data" : [ "cloned-entity" ], "value" : [ "entity-created" ] } }
      ],
      "PROVIDES VARIABLES" : [ "cloned_entity" ]
    }
  }');
  $items['rules_clone_invoice'] = entity_import('rules_config', '{ "rules_clone_invoice" : {
      "LABEL" : "Clone invoice",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Invoice" ],
      "REQUIRES" : [ "rules", "rules_conditional" ],
      "USES VARIABLES" : {
        "invoice_node" : { "label" : "Invoice node", "type" : "node" },
        "cloned_entity" : { "label" : "Cloned entity", "type" : "node", "parameter" : false }
      },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "invoice-node" ],
            "type" : "node",
            "bundle" : { "value" : { "invoice" : "invoice" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "invoice",
              "param_title" : "Tax invoice\\/receipt ID[invoice-node:nid]",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:field-subject" ],
            "value" : "[invoice-node:field-subject] CLONED FROM ID[invoice-node:nid] "
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-for-company" ],
            "value" : [ "invoice-node:field-for-company" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-from-company" ],
            "value" : [ "invoice-node:field-from-company" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-note" ],
            "value" : [ "invoice-node:field-note" ]
          }
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "NOT data_is_empty" : { "data" : [ "invoice-node:field-account" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "entity-created:field-account" ],
                    "value" : [ "invoice-node:field-account" ]
                  }
                }
              ]
            }
          ]
        },
        { "list_add" : {
            "list" : [ "entity-created:field-journal" ],
            "item" : "[site:current-date] - invoice cloned from ID[invoice-node:nid]",
            "pos" : "start"
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : { "data" : [ "cloned-entity" ], "value" : [ "entity-created" ] } }
      ],
      "PROVIDES VARIABLES" : [ "cloned_entity" ]
    }
  }');
  $items['rules_clone_report'] = entity_import('rules_config', '{ "rules_clone_report" : {
      "LABEL" : "Clone report",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Report" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : {
        "report_node" : { "label" : "Report node", "type" : "node" },
        "cloned_entity" : { "label" : "Cloned entity", "type" : "node", "parameter" : false }
      },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "report-node" ],
            "type" : "node",
            "bundle" : { "value" : { "report" : "report" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "report",
              "param_title" : "[report-node:title] CLONED",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:field-reporting-period:value" ],
            "value" : [ "report-node:field-reporting-period:value" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-reporting-period:value2" ],
            "value" : [ "report-node:field-reporting-period:value2" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-report-type" ],
            "value" : [ "report-node:field-report-type" ]
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : { "data" : [ "cloned-entity" ], "value" : [ "entity-created" ] } }
      ],
      "PROVIDES VARIABLES" : [ "cloned_entity" ]
    }
  }');
  $items['rules_clone_reporting_group'] = entity_import('rules_config', '{ "rules_clone_reporting_group" : {
      "LABEL" : "Clone reporting group",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Report" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : {
        "report_group_node" : { "label" : "Report group node", "type" : "node" },
        "cloned_entity" : { "label" : "Cloned entity", "type" : "node", "parameter" : false }
      },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "report-group-node" ],
            "type" : "node",
            "bundle" : { "value" : { "reporting_group" : "reporting_group" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "reporting_group",
              "param_title" : "temp report group title",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:title" ],
            "value" : "[report-group-node:title] CLONED"
          }
        },
        { "data_set" : { "data" : [ "cloned-entity" ], "value" : [ "entity-created" ] } }
      ],
      "PROVIDES VARIABLES" : [ "cloned_entity" ]
    }
  }');
  $items['rules_clone_time_record'] = entity_import('rules_config', '{ "rules_clone_time_record" : {
      "LABEL" : "Clone time record",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "TimeRecord" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : {
        "time_record_node" : { "label" : "Time record node", "type" : "node" },
        "cloned_entity" : { "label" : "Cloned entity", "type" : "node", "parameter" : false }
      },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "time-record-node" ],
            "type" : "node",
            "bundle" : { "value" : { "time_record" : "time_record" } }
          }
        },
        { "NOT data_is_empty" : { "data" : [ "time-record-node:field-invoice" ] } },
        { "NOT data_is_empty" : { "data" : [ "time-record-node:field-from" ] } },
        { "NOT data_is_empty" : { "data" : [ "time-record-node:field-to" ] } }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "time_record",
              "param_title" : "Time record ID[ temp",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "time-record-node" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:title" ],
            "value" : "Time record NID [entity-created:nid]"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-reporting-period:value" ],
            "value" : [ "site:current-date" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-reporting-period:value2" ],
            "value" : [ "site:current-date" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-note" ],
            "value" : "[time-record-node:field-note] CLONE"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-hourly-rate" ],
            "value" : [ "time-record-node:field-hourly-rate" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-invoice" ],
            "value" : [ "time-record-node:field-invoice" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-from" ],
            "value" : [ "time-record-node:field-from" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-to" ],
            "value" : [ "time-record-node:field-to" ]
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : { "data" : [ "cloned-entity" ], "value" : [ "entity-created" ] } }
      ],
      "PROVIDES VARIABLES" : [ "cloned_entity" ]
    }
  }');
  $items['rules_clone_transaction'] = entity_import('rules_config', '{ "rules_clone_transaction" : {
      "LABEL" : "Clone transaction",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules", "rules_conditional" ],
      "USES VARIABLES" : {
        "transaction_node" : { "label" : "Transaction node", "type" : "node" },
        "cloned_entity" : { "label" : "Cloned entity", "type" : "node", "parameter" : false }
      },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "transaction",
              "param_title" : "Transaction NID [node:nid]",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:field-date" ],
            "value" : [ "transaction-node:field-date" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-note" ],
            "value" : "[transaction-node:field-note] CLONE"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-amount" ],
            "value" : [ "transaction-node:field-amount" ]
          }
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "NOT data_is_empty" : { "data" : [ "transaction-node:field-invoice" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "entity-created:field-invoice" ],
                    "value" : [ "transaction-node:field-invoice" ]
                  }
                }
              ]
            },
            { "ELSE" : [
                { "data_set" : { "data" : [ "entity-created:field-invoice" ], "value" : [ "" ] } }
              ]
            }
          ]
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "NOT data_is_empty" : { "data" : [ "transaction-node:field-from" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "entity-created:field-from" ],
                    "value" : [ "transaction-node:field-from" ]
                  }
                }
              ]
            },
            { "ELSE" : [ { "data_set" : { "data" : [ "entity-created:field-from" ] } } ] }
          ]
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "NOT data_is_empty" : { "data" : [ "transaction-node:field-to" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "entity-created:field-to" ],
                    "value" : [ "transaction-node:field-to" ]
                  }
                }
              ]
            },
            { "ELSE" : [ { "data_set" : { "data" : [ "entity-created:field-to" ] } } ] }
          ]
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : { "data" : [ "cloned-entity" ], "value" : [ "entity-created" ] } }
      ],
      "PROVIDES VARIABLES" : [ "cloned_entity" ]
    }
  }');
  $items['rules_clone_transaction_match'] = entity_import('rules_config', '{ "rules_clone_transaction_match" : {
      "LABEL" : "Clone transaction match",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : {
        "transaction_match_node" : { "label" : "Transaction match node", "type" : "node" },
        "cloned_entity" : { "label" : "Cloned entity", "type" : "node", "parameter" : false }
      },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-match-node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction_match" : "transaction_match" } }
          }
        },
        { "NOT data_is_empty" : { "data" : [ "transaction-match-node:field-from" ] } },
        { "NOT data_is_empty" : { "data" : [ "transaction-match-node:field-to" ] } }
      ],
      "DO" : [
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "transaction_match",
              "param_title" : "Temp title",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:title" ],
            "value" : "Transaction match NID [entity-created:nid]"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-from" ],
            "value" : [ "transaction-match-node:field-from" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-to" ],
            "value" : [ "transaction-match-node:field-to" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-match-text" ],
            "value" : "[transaction-match-node:field-match-text] CLONED"
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : { "data" : [ "cloned-entity" ], "value" : [ "entity-created" ] } }
      ],
      "PROVIDES VARIABLES" : [ "cloned_entity" ]
    }
  }');
  $items['rules_create_transaction_from_time_record'] = entity_import('rules_config', '{ "rules_create_transaction_from_time_record" : {
      "LABEL" : "Create Transaction from Time record",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "TimeRecord" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "time_record_node" : { "label" : "Time record node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "time-record-node" ],
            "type" : "node",
            "bundle" : { "value" : { "time_record" : "time_record" } }
          }
        },
        { "data_is_empty" : { "data" : [ "time-record-node:field-transaction" ] } },
        { "NOT data_is_empty" : { "data" : [ "time-record-node:field-invoice" ] } },
        { "NOT data_is_empty" : { "data" : [ "time-record-node:field-from" ] } },
        { "NOT data_is_empty" : { "data" : [ "time-record-node:field-to" ] } }
      ],
      "DO" : [
        { "data_calc" : {
            "USING" : {
              "input_1" : [ "time-record-node:field-reporting-period:duration" ],
              "op" : "\\/",
              "input_2" : "3600"
            },
            "PROVIDE" : { "result" : { "hours_worked" : "Hours worked" } }
          }
        },
        { "data_calc" : {
            "USING" : {
              "input_1" : [ "hours-worked" ],
              "op" : "*",
              "input_2" : [ "time-record-node:field-hourly-rate" ]
            },
            "PROVIDE" : { "result" : { "amount_earned" : "Amount Earned" } }
          }
        },
        { "entity_create" : {
            "USING" : {
              "type" : "node",
              "param_type" : "transaction",
              "param_title" : "Temp title",
              "param_author" : [ "site:current-user" ]
            },
            "PROVIDE" : { "entity_created" : { "entity_created" : "Created entity" } }
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "entity-created:title" ],
            "value" : "Transaction NID [entity-created:nid]"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-date" ],
            "value" : [ "time-record-node:field-reporting-period:value" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-note" ],
            "value" : "Labour | [time-record-node:field-note] | [time-record-node:field_reporting_period] | Duration [hours-worked:value]h @ $[time-record-node:field-hourly-rate] per hour"
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-from" ],
            "value" : [ "time-record-node:field-from" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-to" ],
            "value" : [ "time-record-node:field-to" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-amount" ],
            "value" : [ "amount-earned" ]
          }
        },
        { "data_set" : {
            "data" : [ "entity-created:field-invoice" ],
            "value" : [ "time-record-node:field-invoice" ]
          }
        },
        { "entity_save" : { "data" : [ "entity-created" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "time-record-node:field-transaction" ],
            "value" : [ "entity-created" ]
          }
        }
      ]
    }
  }');
  $items['rules_link_condition_clone_button'] = entity_import('rules_config', '{ "rules_link_condition_clone_button" : {
      "LABEL" : "Rules link: Clone button condition",
      "PLUGIN" : "and",
      "OWNER" : "rules",
      "USES VARIABLES" : { "node" : { "type" : "node", "label" : "node" } },
      "AND" : []
    }
  }');
  $items['rules_link_condition_set_time_end'] = entity_import('rules_config', '{ "rules_link_condition_set_time_end" : {
      "LABEL" : "Rules link: Set time end condition",
      "PLUGIN" : "and",
      "OWNER" : "rules",
      "TAGS" : [ "TimeRecord" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "node" : { "label" : "node", "type" : "node" } },
      "AND" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "node" ],
            "type" : "node",
            "bundle" : { "value" : { "time_record" : "time_record" } }
          }
        },
        { "data_is_empty" : { "data" : [ "node:field-transaction" ] } }
      ]
    }
  }');
  $items['rules_link_set_clone_button'] = entity_import('rules_config', '{ "rules_link_set_clone_button" : {
      "LABEL" : "Rules link: Clone button rules set",
      "PLUGIN" : "rule set",
      "OWNER" : "rules",
      "REQUIRES" : [ "rules", "rules_conditional" ],
      "USES VARIABLES" : { "node" : { "type" : "node", "label" : "node" } },
      "RULES" : [
        { "RULE" : {
            "PROVIDE" : { "variable_added" : { "variable_added" : "Added variable" } },
            "IF" : [
              { "entity_is_of_bundle" : {
                  "entity" : [ "node" ],
                  "type" : "node",
                  "bundle" : { "value" : {
                      "account" : "account",
                      "invoice" : "invoice",
                      "report" : "report",
                      "reporting_group" : "reporting_group",
                      "time_record" : "time_record",
                      "transaction" : "transaction",
                      "transaction_match" : "transaction_match"
                    }
                  }
                }
              }
            ],
            "DO" : [
              { "variable_add" : {
                  "USING" : { "type" : "node" },
                  "PROVIDE" : { "variable_added" : { "variable_added" : "Added variable" } }
                }
              },
              { "SWITCH" : {
                  "USING" : { "data" : [ "node:type" ] },
                  "DO" : [
                    { "CASE" : {
                        "USING" : { "value" : "transaction" },
                        "DO" : [
                          { "component_rules_clone_transaction" : {
                              "USING" : { "transaction_node" : [ "node" ] },
                              "PROVIDE" : { "cloned_entity" : { "cloned_entity" : "Cloned entity" } }
                            }
                          },
                          { "data_set" : { "data" : [ "variable-added" ], "value" : [ "cloned-entity" ] } }
                        ]
                      }
                    },
                    { "CASE" : {
                        "USING" : { "value" : "account" },
                        "DO" : [
                          { "component_rules_clone_account" : {
                              "USING" : { "account_node" : [ "node" ] },
                              "PROVIDE" : { "cloned_entity" : { "cloned_entity" : "Cloned entity" } }
                            }
                          },
                          { "data_set" : { "data" : [ "variable-added" ], "value" : [ "cloned-entity" ] } }
                        ]
                      }
                    },
                    { "CASE" : {
                        "USING" : { "value" : "invoice" },
                        "DO" : [
                          { "component_rules_clone_invoice" : {
                              "USING" : { "invoice_node" : [ "node" ] },
                              "PROVIDE" : { "cloned_entity" : { "cloned_entity" : "Cloned entity" } }
                            }
                          },
                          { "data_set" : { "data" : [ "variable-added" ], "value" : [ "cloned-entity" ] } }
                        ]
                      }
                    },
                    { "CASE" : {
                        "USING" : { "value" : "report" },
                        "DO" : [
                          { "component_rules_clone_report" : {
                              "USING" : { "report_node" : [ "node" ] },
                              "PROVIDE" : { "cloned_entity" : { "cloned_entity" : "Cloned entity" } }
                            }
                          },
                          { "data_set" : { "data" : [ "variable-added" ], "value" : [ "cloned-entity" ] } }
                        ]
                      }
                    },
                    { "CASE" : {
                        "USING" : { "value" : "time_record" },
                        "DO" : [
                          { "component_rules_clone_time_record" : {
                              "USING" : { "time_record_node" : [ "node" ] },
                              "PROVIDE" : { "cloned_entity" : { "cloned_entity" : "Cloned entity" } }
                            }
                          },
                          { "data_set" : { "data" : [ "variable-added" ], "value" : [ "cloned-entity" ] } }
                        ]
                      }
                    },
                    { "CASE" : {
                        "USING" : { "value" : "transaction_match" },
                        "DO" : [
                          { "component_rules_clone_transaction_match" : {
                              "USING" : { "transaction_match_node" : [ "node" ] },
                              "PROVIDE" : { "cloned_entity" : { "cloned_entity" : "Cloned entity" } }
                            }
                          },
                          { "data_set" : { "data" : [ "variable-added" ], "value" : [ "cloned-entity" ] } }
                        ]
                      }
                    },
                    { "CASE" : {
                        "USING" : { "value" : "reporting_group" },
                        "DO" : [
                          { "component_rules_clone_reporting_group" : {
                              "USING" : { "report_group_node" : [ "node" ] },
                              "PROVIDE" : { "cloned_entity" : { "cloned_entity" : "Cloned entity" } }
                            }
                          },
                          { "data_set" : { "data" : [ "variable-added" ], "value" : [ "cloned-entity" ] } }
                        ]
                      }
                    }
                  ]
                }
              },
              { "redirect" : {
                  "url" : "node\\/[variable-added:nid]\\/edit?destination=[site:current-page:path]",
                  "destination" : "1"
                }
              }
            ],
            "LABEL" : "Clone button selector"
          }
        }
      ]
    }
  }');
  $items['rules_link_set_set_time_end'] = entity_import('rules_config', '{ "rules_link_set_set_time_end" : {
      "LABEL" : "Rules link: Set time end rules set",
      "PLUGIN" : "rule set",
      "OWNER" : "rules",
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "node" : { "label" : "node", "type" : "node" } },
      "RULES" : [
        { "RULE" : {
            "IF" : [
              { "entity_is_of_bundle" : {
                  "entity" : [ "node" ],
                  "type" : "node",
                  "bundle" : { "value" : { "time_record" : "time_record" } }
                }
              },
              { "data_is_empty" : { "data" : [ "node:field-transaction" ] } }
            ],
            "DO" : [
              { "component_rules_set_time_record_end_date_to_current_time" : { "time_record_node" : [ "node" ] } }
            ],
            "LABEL" : "Set time end rule"
          }
        }
      ]
    }
  }');
  $items['rules_match_transaction'] = entity_import('rules_config', '{ "rules_match_transaction" : {
      "LABEL" : "Match transaction",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules", "views_rules", "rules_conditional" ],
      "USES VARIABLES" : { "transaction_node" : { "label" : "Transaction node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        },
        { "NOT data_is_empty" : { "data" : [ "transaction-node:field-note" ] } },
        { "OR" : [
            { "data_is_empty" : { "data" : [ "transaction-node:field-from" ] } },
            { "data_is_empty" : { "data" : [ "transaction-node:field-to" ] } }
          ]
        }
      ],
      "DO" : [
        { "VIEW LOOP" : {
            "VIEW" : "matches",
            "DISPLAY" : "views_rules_1",
            "ROW VARIABLES" : {
              "nid" : { "nid" : "Nid" },
              "field_match_text" : { "field_match_text" : "Match if contains" },
              "field_from" : { "field_from" : "Set FROM" },
              "field_to" : { "field_to" : "Set TO" }
            },
            "DO" : [
              { "CONDITIONAL" : [
                  {
                    "IF" : { "text_matches" : {
                        "text" : [ "transaction-node:field-note" ],
                        "match" : [ "field-match-text" ]
                      }
                    },
                    "DO" : [
                      { "data_set" : { "data" : [ "transaction-node:field-from" ], "value" : [ "field-from" ] } },
                      { "data_set" : { "data" : [ "transaction-node:field-to" ], "value" : [ "field-to" ] } },
                      { "data_set" : {
                          "data" : [ "transaction-node:field-note" ],
                          "value" : "[transaction-node:field-note]\\r\\n### [site:current-date] - Transaction automatically matched based on rule ID[nid:nid] ([field-match-text:value])"
                        }
                      },
                      { "drupal_message" : { "message" : "Transaction ID[transaction-node:nid] matched to rule ID[nid:nid] ([field-match-text:value])" } }
                    ]
                  }
                ]
              }
            ]
          }
        }
      ]
    }
  }');
  $items['rules_set_time_record_end_date_to_current_time'] = entity_import('rules_config', '{ "rules_set_time_record_end_date_to_current_time" : {
      "LABEL" : "Set time record end date to current time",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "TimeRecord" ],
      "REQUIRES" : [ "rules" ],
      "USES VARIABLES" : { "time_record_node" : { "label" : "Time record node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "time-record-node" ],
            "type" : "node",
            "bundle" : { "value" : { "time_record" : "time_record" } }
          }
        },
        { "data_is_empty" : { "data" : [ "time-record-node:field-transaction" ] } }
      ],
      "DO" : [
        { "data_set" : {
            "data" : [ "time-record-node:field-reporting-period:value2" ],
            "value" : [ "site:current-date" ]
          }
        },
        { "drupal_message" : { "message" : "End time re-set for time record ID [time-record-node:nid]" } },
        { "redirect" : { "url" : "timesheet" } }
      ]
    }
  }');
  $items['rules_update_transaction_parts'] = entity_import('rules_config', '{ "rules_update_transaction_parts" : {
      "LABEL" : "Update transaction parts",
      "PLUGIN" : "rule",
      "OWNER" : "rules",
      "TAGS" : [ "Transactions" ],
      "REQUIRES" : [ "rules", "rules_conditional" ],
      "USES VARIABLES" : { "transaction_node" : { "label" : "Transaction node", "type" : "node" } },
      "IF" : [
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node" ],
            "type" : "node",
            "bundle" : { "value" : { "transaction" : "transaction" } }
          }
        },
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node:field-part-from" ],
            "type" : "node",
            "bundle" : { "value" : { "part" : "part" } }
          }
        },
        { "entity_is_of_bundle" : {
            "entity" : [ "transaction-node:field-part-to" ],
            "type" : "node",
            "bundle" : { "value" : { "part" : "part" } }
          }
        }
      ],
      "DO" : [
        { "CONDITIONAL" : [
            {
              "IF" : { "NOT data_is_empty" : { "data" : [ "transaction-node:field-amount" ] } },
              "DO" : [
                { "data_calc" : {
                    "USING" : {
                      "input_1" : [ "transaction-node:field-amount" ],
                      "op" : "*",
                      "input_2" : "-1"
                    },
                    "PROVIDE" : { "result" : { "result" : "Calculation result" } }
                  }
                },
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-from:field-amount" ],
                    "value" : [ "result" ]
                  }
                }
              ]
            }
          ]
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "data_is_empty" : { "data" : [ "transaction-node:field-from" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-from:field-account" ],
                    "value" : [ "" ]
                  }
                }
              ]
            },
            { "ELSE" : [
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-from:field-account" ],
                    "value" : [ "transaction-node:field-from" ]
                  }
                }
              ]
            }
          ]
        },
        { "entity_save" : { "data" : [ "transaction-node:field-part-from" ], "immediate" : "1" } },
        { "data_set" : {
            "data" : [ "transaction-node:field-part-to:field-amount" ],
            "value" : [ "transaction-node:field-amount" ]
          }
        },
        { "CONDITIONAL" : [
            {
              "IF" : { "data_is_empty" : { "data" : [ "transaction-node:field-to" ] } },
              "DO" : [
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-to:field-account" ],
                    "value" : [ "" ]
                  }
                }
              ]
            },
            { "ELSE" : [
                { "data_set" : {
                    "data" : [ "transaction-node:field-part-to:field-account" ],
                    "value" : [ "transaction-node:field-to" ]
                  }
                }
              ]
            }
          ]
        },
        { "entity_save" : { "data" : [ "transaction-node:field-part-to" ], "immediate" : "1" } }
      ]
    }
  }');
  return $items;
}
